@@ -1,6 +1,6 @@
 package Map::Tube::Line;
 
-$Map::Tube::Node::VERSION = '2.46';
+$Map::Tube::Node::VERSION = '2.47';
 
 =head1 NAME
 
@@ -8,26 +8,23 @@ Map::Tube::Line - Class to represent the line in the map.
 
 =head1 VERSION
 
-Version 2.46
+Version 2.47
 
 =cut
 
 use 5.006;
 use Data::Dumper;
+use Map::Tube::Exception;
+use Map::Tube::Error qw(:constants);
 
 use Moo;
 use namespace::clean;
 
 use overload q{""} => 'as_string', fallback => 1;
 
-has name  => (is => 'ro', required => 1);
-has color => (is => 'ro');
-
-sub as_string {
-    my ($self) = @_;
-
-    return $self->name;
-}
+has name     => (is => 'ro', required => 1);
+has color    => (is => 'ro');
+has stations => (is => 'rw');
 
 =head1 METHODS
 
@@ -39,6 +36,55 @@ Returns the line name.
 
 Returns the color name of the line, if available.
 
+=head2 add_station($station)
+
+Adds station (object of type L<Map::Tube::Node>) to the line.
+
+=cut
+
+sub add_station {
+    my ($self, $station) = @_;
+
+    my @caller = caller(0);
+    @caller = caller(2) if $caller[3] eq '(eval)';
+
+    Map::Tube::Exception->throw({
+        method      => __PACKAGE__."::add_station",
+        message     => "ERROR: Missing station.",
+        status      => ERROR_MISSING_STATION,
+        filename    => $caller[1],
+        line_number => $caller[2] })
+        unless (defined $station);
+
+    Map::Tube::Exception->throw({
+        method      => __PACKAGE__."::add_station",
+        message     => "ERROR: Invalid station.",
+        status      => ERROR_INVALID_STATION,
+        filename    => $caller[1],
+        line_number => $caller[2] })
+        unless (ref($station) eq 'Map::Tube::Node');
+
+    push @{$self->{stations}}, $station;
+}
+
+=head2 get_stations()
+
+Returns a ref to the list of stations (object of type L<Map::Tube::Node>) of the line.
+
+=cut
+
+sub get_stations {
+    my ($self) = @_;
+
+    return $self->stations;
+}
+
+sub as_string {
+    my ($self) = @_;
+
+    return $self->name;
+}
+
 =head1 AUTHOR
 
 Mohammad S Anwar, C<< <mohammad.anwar at yahoo.com> >>
